@@ -6,7 +6,7 @@ import logging
 import time
 from datetime import timedelta
 from ipaddress import IPv4Address
-from typing import Dict, FrozenSet, List, Optional, Sequence, Set
+from typing import Any, Dict, FrozenSet, List, Optional, Sequence, Set, Union
 
 from async_upnp_client.client import (
     EventCallbackType,
@@ -14,10 +14,15 @@ from async_upnp_client.client import (
     UpnpDevice,
     UpnpService,
     UpnpStateVariable,
+    UpnpValueError,
 )
 from async_upnp_client.const import SsdpHeaders
 from async_upnp_client.event_handler import UpnpEventHandler
-from async_upnp_client.exceptions import UpnpConnectionError, UpnpError
+from async_upnp_client.exceptions import (
+    UpnpConnectionError,
+    UpnpError,
+    UpnpResponseError,
+)
 from async_upnp_client.search import async_search
 from async_upnp_client.ssdp import SSDP_MX
 
@@ -322,6 +327,8 @@ class UpnpProfileDevice:
             empty state_variables list.
         :return: time until this next needs to be called, or None if manual
             resubscription is not needed.
+        :raise UpnpResponseError: Device rejected subscription request.
+            State variables will need to be polled.
         :raise UpnpError or subclass: Failed to subscribe to all interesting
             services.
         """
@@ -345,7 +352,10 @@ class UpnpProfileDevice:
                     )
                     self._subscriptions[new_sid] = now + timeout.total_seconds()
         except UpnpError as err:
-            _LOGGER.warning("Failed subscribing to service: %r", err)
+            if isinstance(err, UpnpResponseError) and not self._subscriptions:
+                _LOGGER.info("Device rejected subscription request: %r", err)
+            else:
+                _LOGGER.warning("Failed subscribing to service: %r", err)
             # Unsubscribe anything that was subscribed, no half-done subscriptions
             try:
                 await self.async_unsubscribe_services()
@@ -394,6 +404,45 @@ class UpnpProfileDevice:
         """Get current service subscription state."""
         return bool(self._subscriptions)
 
+    async def _async_poll_state_variables(
+        self, service_name: str, action_names: Union[str, Sequence[str]], **in_args: Any
+    ) -> None:
+        """Update state variables by polling actions that return their values.
+
+        Assumes that the actions's relatedStateVariable names the correct state
+        variable for updating.
+        """
+        service = self._service(service_name)
+        if not service:
+            _LOGGER.debug("Can't poll missing service %s", service_name)
+            return
+
+        if isinstance(action_names, str):
+            action_names = [action_names]
+
+        changed_state_variables: List[UpnpStateVariable] = []
+
+        for action_name in action_names:
+            action = service.action(action_name)
+            result = await action.async_call(**in_args)
+
+            for arg in action.arguments:
+                if arg.direction != "out":
+                    continue
+                if arg.name not in result:
+                    continue
+                if arg.related_state_variable.value == arg.value:
+                    continue
+
+                try:
+                    arg.related_state_variable.value = arg.value
+                except UpnpValueError:
+                    continue
+                changed_state_variables.append(arg.related_state_variable)
+
+        if changed_state_variables:
+            self._on_event(service, changed_state_variables)
+
     def _on_event(
         self, service: UpnpService, state_variables: Sequence[UpnpStateVariable]
     ) -> None:
